@@ -40,8 +40,9 @@ F3ModelFun[[1]] <-function(K1,logL,df,m_nf){
   dd<-c((sum(bmw)),(sum(bmw^2)),sum((bmw-0.5)^2))
   w<-w1+sum((bmw - (as.matrix(c(1:m_sam)) - 0.5)/m_sam)^2)
   u<- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
+  D<-as.numeric(ks.test(bmw,"punif")[2])
+  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(w),D))
   D<-as.numeric(ks.test(bmw,"punif")[[1]][1])
-  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(w),(1-pkolm(D,m_sam))))
 
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("0MG",round(abc,4),round(AIC,4),round(m,4)," "," "," "," "," "," "," "," ",round(sigma,4)," "," "," "," "," "," "," "," ",round(mix_pi,4)," "," "," "," "," "," "," "," "," "," "," "," "," "," "," "," "," "," "," ",round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(w,4),tt[4],round(D,4),tt[5])
@@ -94,6 +95,7 @@ F3ModelFun[[2]]  <-function(K1,logL,df,m_nf){
     }
     sigma[2]<-sigma[1]+aa3
     sigma[3]<-sigma[1]
+    if(sum(sigma < 1e-30)>=1){break}
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
@@ -122,8 +124,9 @@ F3ModelFun[[2]]  <-function(K1,logL,df,m_nf){
   dd <- as.matrix(c(sum(P2),sum(P2^2),sum((P2-0.5)^2)))
   WW2 <- 1/(12*m_sam) + sum((P2 - (as.matrix(c(1:m_sam)) - 0.5)/m_sam)^2)
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
+  D <- as.numeric(ks.test(P2,"punif")[2])
+  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),D))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
-  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
 
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("1MG-AD",round(abc,4),round(AIC,4),round(t(m),4)," "," "," "," "," "," ",round(t(sigma),4)," "," "," "," "," "," ",round(t(mix_pi),4)," "," "," "," "," "," ",round(B1[1],4),round(B1[2],4)," ",round(B1[3],4)," "," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
@@ -182,6 +185,7 @@ F3ModelFun[[3]]  <-function(K1,logL,df,m_nf)
     }
     sigma[2]<-sigma[1]+aa3
     sigma[3]<-sigma[1]
+    if(sum(sigma < 1e-30)>=1){break}
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
@@ -210,8 +214,9 @@ F3ModelFun[[3]]  <-function(K1,logL,df,m_nf)
   dd <- as.matrix(c(sum(P2),sum(P2^2),sum((P2-0.5)^2)))
   WW2 <- 1/(12*m_sam) + sum((P2 - (as.matrix(c(1:m_sam)) - 0.5)/m_sam)^2)
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
+  D <- as.numeric(ks.test(P2,"punif")[2])
+  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),D))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
-  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
 
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("1MG-A",round(abc,4),round(AIC,4),round(t(m),4)," "," "," "," "," "," ",round(t(sigma),4)," "," "," "," "," "," ",round(t(mix_pi),4)," "," "," "," "," "," ",round(B1[1],4),round(B1[2],4)," "," "," "," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
@@ -269,6 +274,7 @@ F3ModelFun[[4]]  <-function(K1,logL,df,m_nf){
     }
     sigma[2]<-sigma[1]+aa3
     sigma[3]<-sigma[1]
+    if(sum(sigma < 1e-30)>=1){break}
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
@@ -297,8 +303,9 @@ F3ModelFun[[4]]  <-function(K1,logL,df,m_nf){
   dd <- as.matrix(c(sum(P2),sum(P2^2),sum((P2-0.5)^2)))
   WW2 <- 1/(12*m_sam) + sum((P2 - (as.matrix(c(1:m_sam)) - 0.5)/m_sam)^2)
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
+  D <- as.numeric(ks.test(P2,"punif")[2])
+  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),D))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
-  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
 
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("1MG-EAD",round(abc,4),round(AIC,4),round(t(m),4)," "," "," "," "," "," ",round(t(sigma),4)," "," "," "," "," "," ",round(t(mix_pi),4)," "," "," "," "," "," ",round(B1[1],4),round(B1[2],4)," "," "," "," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
@@ -356,6 +363,7 @@ F3ModelFun[[5]]  <-function(K1,logL,df,m_nf){
     }
     sigma[2]<-sigma[1]+aa3
     sigma[3]<-sigma[1]
+    if(sum(sigma < 1e-30)>=1){break}
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
@@ -384,8 +392,9 @@ F3ModelFun[[5]]  <-function(K1,logL,df,m_nf){
   dd <- as.matrix(c(sum(P2),sum(P2^2),sum((P2-0.5)^2)))
   WW2 <- 1/(12*m_sam) + sum((P2 - (as.matrix(c(1:m_sam)) - 0.5)/m_sam)^2)
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
+  D <- as.numeric(ks.test(P2,"punif")[2])
+  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),D))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
-  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
 
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("1MG-NCD",round(abc,4),round(AIC,4),round(t(m),4)," "," "," "," "," "," ",round(t(sigma),4)," "," "," "," "," "," ",round(t(mix_pi),4)," "," "," "," "," "," ",round(B1[1],4),round(B1[2],4)," "," "," "," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
@@ -446,6 +455,7 @@ F3ModelFun[[6]]  <-function(K1,logL,df,m_nf){
     sigma[3]<-sigma[1];sigma[7]<-sigma[1];sigma[9]<-sigma[1]
     sigma[2]<-sigma[1]+g_a[1];sigma[4]<-sigma[1]+g_a[2];sigma[5]<-sigma[1]+g_a[5]
     sigma[6]<-sigma[1]+g_a[3];sigma[8]<-sigma[1]+g_a[4]
+    if(sum(sigma < 1e-30)>=1){break}
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
@@ -475,8 +485,9 @@ F3ModelFun[[6]]  <-function(K1,logL,df,m_nf){
   dd <- as.matrix(c(sum(P2),sum(P2^2),sum((P2-0.5)^2)))
   WW2 <- 1/(12*m_sam) + sum((P2 - (as.matrix(c(1:m_sam)) - 0.5)/m_sam)^2)
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
+  D <- as.numeric(ks.test(P2,"punif")[2])
+  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),D))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
-  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
 
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("2MG-ADI",round(abc,4),round(AIC,4),round(t(m),4),round(t(sigma),4),round(t(mix_pi),4),round(t(B5),4),round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
@@ -569,6 +580,7 @@ F3ModelFun[[7]]  <-function(K1,logL,df,m_nf){
     sigma[3]<-sigma[1];sigma[7]<-sigma[1];sigma[9]<-sigma[1]
     sigma[2]<-sigma[1]+g_a[1];sigma[4]<-sigma[1]+g_a[2]
     sigma[5]<-sigma[1]+g_a[3];sigma[6]<-sigma[1]+g_a[2];sigma[8]<-sigma[1]+g_a[1]
+    if(sum(sigma < 1e-30)>=1){break}
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
@@ -597,8 +609,9 @@ F3ModelFun[[7]]  <-function(K1,logL,df,m_nf){
   dd <- as.matrix(c(sum(P2),sum(P2^2),sum((P2-0.5)^2)))
   WW2 <- 1/(12*m_sam) + sum((P2 - (as.matrix(c(1:m_sam)) - 0.5)/m_sam)^2)
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
+  D <- as.numeric(ks.test(P2,"punif")[2])
+  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),D))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
-  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
 
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("2MG-AD",round(abc,4),round(AIC,4),round(t(m),4),round(t(sigma),4),round(t(mix_pi),4),round(t(B61),4)," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
@@ -703,6 +716,7 @@ F3ModelFun[[8]]  <-function(K1,logL,df,m_nf){
     sigma[3]<-sigma[1];sigma[7]<-sigma[1];sigma[9]<-sigma[1]
     sigma[2]<-sigma[1]+g_a[1];sigma[4]<-sigma[1]+g_a[2]
     sigma[5]<-sigma[1]+g_a[3];sigma[6]<-sigma[1]+g_a[2];sigma[8]<-sigma[1]+g_a[1]
+    if(sum(sigma < 1e-30)>=1){break}
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
@@ -732,8 +746,9 @@ F3ModelFun[[8]]  <-function(K1,logL,df,m_nf){
   dd <- as.matrix(c(sum(P2),sum(P2^2),sum((P2-0.5)^2)))
   WW2 <- 1/(12*m_sam) + sum((P2 - (as.matrix(c(1:m_sam)) - 0.5)/m_sam)^2)
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
+  D <- as.numeric(ks.test(P2,"punif")[2])
+  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),D))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
-  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
 
 
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
@@ -816,6 +831,7 @@ F3ModelFun[[9]]  <-function(K1,logL,df,m_nf){
     }
     sigma[6]<-sigma[1];sigma[2]<-sigma[1]+g_a[1];sigma[4]<-sigma[1]+g_a[1]
     sigma[5]<-sigma[1]+g_a[1];sigma[3]<-sigma[1]+g_a[2]
+    if(sum(sigma < 1e-30)>=1){break}
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
@@ -845,8 +861,9 @@ F3ModelFun[[9]]  <-function(K1,logL,df,m_nf){
   dd <- as.matrix(c(sum(P2),sum(P2^2),sum((P2-0.5)^2)))
   WW2 <- 1/(12*m_sam) + sum((P2 - (as.matrix(c(1:m_sam)) - 0.5)/m_sam)^2)
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
+  D <- as.numeric(ks.test(P2,"punif")[2])
+  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),D))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
-  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
 
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("2MG-EA",round(abc,4),round(AIC,4),round(t(m),4)," "," "," ",round(t(sigma),4)," "," "," ",round(t(mix_pi),4)," "," "," ",round(t(B81),4)," "," "," "," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
@@ -950,6 +967,7 @@ F3ModelFun[[10]]  <-function(K1,logL,df,m_nf){
     sigma[3]<-sigma[1];sigma[7]<-sigma[1];sigma[9]<-sigma[1]
     sigma[2]<-sigma[1]+g_a[1];sigma[4]<-sigma[1]+g_a[2]
     sigma[5]<-sigma[1]+g_a[3];sigma[6]<-sigma[1]+g_a[2];sigma[8]<-sigma[1]+g_a[1]
+    if(sum(sigma < 1e-30)>=1){break}
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
@@ -978,8 +996,9 @@ F3ModelFun[[10]]  <-function(K1,logL,df,m_nf){
   dd <- as.matrix(c(sum(P2),sum(P2^2),sum((P2-0.5)^2)))
   WW2 <- 1/(12*m_sam) + sum((P2 - (as.matrix(c(1:m_sam)) - 0.5)/m_sam)^2)
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
+  D <- as.numeric(ks.test(P2,"punif")[2])
+  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),D))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
-  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
 
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("2MG-CD",round(abc,4),round(AIC,4),round(t(m),4),round(t(sigma),4),round(t(mix_pi),4),round(t(B91),4)," "," "," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
@@ -1065,6 +1084,7 @@ F3ModelFun[[11]]  <-function(K1,logL,df,m_nf){
     sigma[4]<-sigma[1];sigma[6]<-sigma[1]
     sigma[2]<-sigma[1]+g_a[1];sigma[5]<-sigma[1]+g_a[1]
     sigma[3]<-sigma[1]+g_a[2]
+    if(sum(sigma < 1e-30)>=1){break}
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
@@ -1093,8 +1113,9 @@ F3ModelFun[[11]]  <-function(K1,logL,df,m_nf){
   dd <- as.matrix(c(sum(P2),sum(P2^2),sum((P2-0.5)^2)))
   WW2 <- 1/(12*m_sam) + sum((P2 - (as.matrix(c(1:m_sam)) - 0.5)/m_sam)^2)
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
+  D <- as.numeric(ks.test(P2,"punif")[2])
+  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),D))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
-  tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
 
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("2MG-EAD",round(abc,4),round(AIC,4),round(t(m),4)," "," "," ",round(t(sigma),4)," "," "," ",round(t(mix_pi),4)," "," "," ",round(t(B101),4)," "," "," "," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
@@ -1134,7 +1155,6 @@ if(model=="All models"){
   i<-NULL
   allresult=foreach(i=1:11,.combine = 'rbind')%dopar%{
     requireNamespace("KScorrect")
-    requireNamespace("kolmim")
     F3ModelFun[[i]](K1F23,logLF23,df,m_nf)[[1]]
   }
   stopCluster(cl)
